// Set the dimensions and margins of the graph
const margin = { top: 10, right: 30, bottom: 30, left: 50 },
  width = 760 - margin.left - margin.right,
  height = 470 - margin.top - margin.bottom;

// Append the svg object to the body of the page
const svg = d3
  .select('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',' + margin.top + ')',
  );

// Read the data
d3.csv('data.csv').then(function (data) {
  // Add X axis
  const x = d3
    .scaleLinear()
    .domain(d3.extent(data, (d) => d.year))
    .range([0, width]);
  svg
    .append('g')
    .attr('transform', 'translate(0,' + height + ')')
    .call(d3.axisBottom(x));

  // Add Y axis
  const y = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => +d.average)])
    .range([height, 0]);
  svg.append('g').call(d3.axisLeft(y));

  // Add X axis label
  svg
    .append('text')
    .attr(
      'transform',
      'translate(' +
        width / 2 +
        ' ,' +
        (height + margin.top + 20) +
        ')',
    )
    .style('text-anchor', 'middle')
    .text('Year');

  // Add Y axis label
  svg
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('y', 0 - margin.left)
    .attr('x', 0 - height / 2)
    .attr('dy', '1em')
    .style('text-anchor', 'middle')
    .text('Average');

  // Add the area
  svg
    .append('path')
    .datum(data)
    .attr('fill', '#cce5df')
    .attr('stroke', '#69b3a2')
    .attr('stroke-width', 1.5)
    .attr(
      'd',
      d3
        .area()
        .x(function (d) {
          return x(d.year);
        })
        .y0(y(0))
        .y1(function (d) {
          return y(d.average);
        }),
    );
});
